Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(371)

Unified Diff: recipe_engine/recipe_api.py

Issue 1777003003: recipe_engine: change resource API to use repo root (Closed) Base URL: https://github.com/luci/recipes-py.git@master
Patch Set: review Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « recipe_engine/package.py ('k') | recipe_modules/path/api.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: recipe_engine/recipe_api.py
diff --git a/recipe_engine/recipe_api.py b/recipe_engine/recipe_api.py
index 920cfb580be48e07c6ba9760681185d5926c25fa..28fd9dc20c959dcb84ef81318a79ed32afb1e954 100644
--- a/recipe_engine/recipe_api.py
+++ b/recipe_engine/recipe_api.py
@@ -446,11 +446,11 @@ class RecipeApiPlain(object):
# module.resource('dir').join('subdir', 'file.py')
return self._module.MODULE_DIRECTORY.join('resources', *path)
- def package_resource(self, *path):
+ def package_repo_resource(self, *path):
"""Returns a resource path, where path is relative to the root of
the package where this module is defined.
"""
- return self._module.PACKAGE_DIRECTORY.join(*path)
+ return self._module.PACKAGE_REPO_ROOT.join(*path)
@property
def name(self):
« no previous file with comments | « recipe_engine/package.py ('k') | recipe_modules/path/api.py » ('j') | no next file with comments »
@@ -446,11 +446,11 @@ class RecipeApiPlain(object):
"""Returns a resource path, where path is relative to the root of
- the package where this module is defined.
+ the package repo where this module is defined.
"""

Powered by Google App Engine
This is Rietveld 408576698